import DISNET.objects.DisnetObject as DisnetObject


class DrugObject(DisnetObject.DisnetObject):
    """Class to instance objects of type Drug"""

    def __init__(self, id: (str, int), name: str, molecularType: str = None, chemicalStructure: str = None,
                 inchiKey: str = None):
        DisnetObject.DisnetObject.__init__(self, id)
        self.__name = name
        self.__molecularType = molecularType
        self.__chemicalStructure = chemicalStructure
        self.__inchiKey = inchiKey

    def getName(self) -> str:
        """Returns the name of the Drug"""
        return self.__name

    def getMolecularType(self) -> str:
        """Returns the molecular type of the Drug"""
        return self.__molecularType

    def getChemicalStructure(self) -> str:
        """Returns the chemical structure of the Drug"""
        return self.__chemicalStructure

    def getInchiKey(self) -> str:
        """Returns the inchi key of the Drug"""
        return self.__inchiKey

    def info(self) -> str:
        """Returns the information of the Drug as a string"""
        return "DrugObject: [name: " + str(self.__name) + ", id: " + str(self.getId()) + ", molecularType: " + \
               str(self.__molecularType) + ", chemicalStructure: " + str(self.__chemicalStructure) + \
               ", inchiKey: " + str(self.__inchiKey) + "]"

    def __eq__(self, other) -> bool:
        """Equals to other Drug"""
        if isinstance(other, DrugObject):
            equalName = self.__name == other.getName()
            equalID = self.getId() == other.getId()

            return equalName and equalID
        else:
            return False
