import DISNET.objects.DisnetObject as DisnetObject


class TargetObject(DisnetObject.DisnetObject):
    """Class to instance objects of type Target"""

    def __init__(self, id: (str, int), name: str, targetType: str = None, organismName: str = None):
        DisnetObject.DisnetObject.__init__(self, id)
        self.__name = name
        self.__targetType = targetType
        self.__organismName = organismName

    def getName(self) -> str:
        """Returns the name of the target"""
        return self.__name

    def getTargetType(self) -> str:
        """Returns the target type"""
        return self.__targetType

    def getOrganismName(self) -> str:
        """Returns the organism name"""
        return self.__organismName

    def info(self):
        """Returns the information of the Target as a string"""
        return "TargetObject: [name: " + self.__name + ", id: " + self.getId() + ", organismName: " + \
               self.__organismName + ", targetType: " + self.__targetType + "]"

    def __eq__(self, other) -> bool:
        """Equals to other Target"""
        if isinstance(other, TargetObject):
            equalName = self.__name == other.getName()
            equalID = self.getId() == other.getId()

            return equalID and equalName
        else:
            return False
